@@ -12,7 +12,7 @@
 
 #include <PolkitQt1/Agent/Listener>
 
-class AuthDialog;
+class QuickAuthDialog;
 
 using namespace PolkitQt1::Agent;
 
@@ -46,8 +46,8 @@ public Q_SLOTS:
     void setWIdForAction(const QString &action, qulonglong wID);
 
 private:
-    QPointer<AuthDialog> m_dialog;
-    QPointer<Session> m_session;
+    QPointer<QuickAuthDialog> m_dialog;
+    QPointer<Session> m_session = nullptr;
     bool m_inProgress;
     bool m_gainedAuthorization;
     bool m_wasCancelled;
